@@ -3,6 +3,7 @@
 import re
 
 from enum import Enum
+from flufl.bounce._detectors.simplematch import VALID
 from flufl.bounce.interfaces import (
     IBounceDetector, NoFailures, NoTemporaryFailures)
 from io import BytesIO
@@ -44,6 +45,6 @@ class Microsoft:
                 if scre.search(line):
                     state = ParseState.tag_seen
             elif state is ParseState.tag_seen:
-                if '@' in line:
+                if VALID.match(line.strip()):
                     addresses.add(line.strip())
         return NoTemporaryFailures, set(addresses)
